#!/bin/sh
# --- GLOBALS ---
# Путь к папке на устройстве, где создается архив бэкапа.
# BackupDir="/tmp/Backup"
# Путь к папке с архивом бэкапа на флешке.
BackupFlashDir="/mnt"
# Путь к папке на устройстве, куда распаковывается архив с бэкапом. После перезагрузки данные из этой папки перемещаются
# в корень устройства и восстановление завершается.
BackupRestoredDir="/root/BackupRestored"
# Название архива бэкапа.
BackupName="MpayBackup.tar.gz"
# Путь к архиву с бэкапом на флешке.
BackupFlashArchivePath="$BackupFlashDir/$BackupName"

removeIfExists() {
	local path=$1
	if [ -e $path ]; then rm -r $path; fi
}

recreateDir() {
	local path=$1
	removeIfExists $path
	mkdir -p $path
}

makeBackup() {
	echo "Creating backup, BackupFlashArchivePath=$BackupFlashArchivePath"
	set -x
	removeIfExists $BackupFlashArchivePath
	tar -cvf - \
		/root/cashcore \
		/root/MiniKassir \
		/root/MpaySoftUpdater \
		/root/wifi/wpa_supplicant.conf \
		/root/serial.fil \
		/root/UpdateVersion.txt \
		/root/DeviceInit.ini \
		/root/.DeviceInited \
		/root/.DeviceTested \
		/etc/dhcpcd.conf \
		/etc/passwd \
		/etc/shadow \
		| gzip > $BackupFlashArchivePath
}

restoreFromBackup() {
	set -x
	if [ -e $BackupFlashArchivePath ]; then
		echo "Restoring from backup, BackupFlashArchivePath=$BackupFlashArchivePath, BackupRestoredDir=$BackupRestoredDir"
		recreateDir $BackupRestoredDir
		gunzip -c $BackupFlashArchivePath | tar -C $BackupRestoredDir -xvf -
		sync
	fi
}

initd() {
	if [ -e $BackupRestoredDir ]; then
		echo "Move all from backup restored dir to device root, BackupRestoredDir=$BackupRestoredDir"
		set -x
		rsync -rv --remove-source-files $BackupRestoredDir/* /
		rm -r $BackupRestoredDir
		sync
	fi
}

testArchive() {
	gunzip -c $BackupFlashArchivePath | tar -t >/dev/null
	if [ $? -eq 0 ]; then
		echo 0
	else
		echo 1
	fi
}

case "$1" in
	"") makeBackup;;
	"restore") restoreFromBackup;;
	"initd") initd;;
	"backupFlashArchivePath") echo $BackupFlashArchivePath;;
	"testArchive") testArchive;;
	*) echo "invalid arg: $1";;
esac
